@@ -26,32 +26,60 @@
 
 This AWS Solutions Construct implements an Amazon EventBridge rule to send data to an Amazon Kinesis Data Stream
 
-Here is a minimal deployable pattern definition in Typescript:
+Here is a minimal deployable pattern definition:
+
+Typescript
 
 ```python
-import * as cdk from '@aws-cdk/core';
-import {EventbridgeToKinesisStreams, EventbridgeToKinesisStreamsProps} from "@aws-solutions-constructs/aws-eventbridge-kinesisstreams";
+import { Construct } from 'constructs';
+import { Stack, StackProps, Duration } from 'aws-cdk-lib';
+import { EventbridgeToKinesisStreams, EventbridgeToKinesisStreamsProps } from "@aws-solutions-constructs/aws-eventbridge-kinesisstreams";
+import * as events from 'aws-cdk-lib/aws-events';
 
-const props: EventbridgeToKinesisStreamsProps = {
-    eventRuleProps: {
-      schedule: events.Schedule.rate(Duration.minutes(5)),
-    }
+const constructProps: EventbridgeToKinesisStreamsProps = {
+  eventRuleProps: {
+    schedule: events.Schedule.rate(Duration.minutes(5)),
+  }
 };
 
-new EventbridgeToKinesisStreams(this, 'test-eventbridge-kinesis-streams', props);
+new EventbridgeToKinesisStreams(this, 'test-eventbridge-kinesis-streams', constructProps);
 ```
 
-## Initializer
+Python
 
-```text
-new EventbridgeToKinesisStreams(scope: Construct, id: string, props: EventbridgeToKinesisStreamsProps);
+```Python
+from aws_solutions_constructs.aws_eventbridge_kinesis_streams import EventbridgeToKinesisStreams, EventbridgeToKinesisStreamsProps
+from aws_cdk import (
+    aws_events as events,
+    Duration,
+    Stack
+)
+from constructs import Construct
+
+EventbridgeToKinesisStreams(self, 'test-eventbridge-kinesis-streams',
+    event_rule_props=events.RuleProps(
+        schedule=events.Schedule.rate(Duration.minutes(5)),
+    ))
 ```
 
-*Parameters*
+Java
 
-* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
-* id `string`
-* props [`EventbridgeToKinesisStreamsProps`](#pattern-construct-props)
+```java
+import software.constructs.Construct;
+
+import software.amazon.awscdk.Stack;
+import software.amazon.awscdk.StackProps;
+import software.amazon.awscdk.Duration;
+import software.amazon.awscdk.services.events.*;
+import software.amazon.awsconstructs.services.eventbridgekinesisstreams.*;
+
+new EventbridgeToKinesisStreams(this, "test-eventbridge-kinesis-streams",
+        new EventbridgeToKinesisStreamsProps.Builder()
+                .eventRuleProps(new RuleProps.Builder()
+                        .schedule(Schedule.rate(Duration.minutes(5)))
+                        .build())
+                .build());
+```
 
 ## Pattern Construct Props
 
@@ -93,7 +121,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
